(function () {

/* Imports */
var Meteor = Package.meteor.Meteor;
var global = Package.meteor.global;
var meteorEnv = Package.meteor.meteorEnv;
var ECMAScript = Package.ecmascript.ECMAScript;
var meteorInstall = Package.modules.meteorInstall;
var Buffer = Package.modules.Buffer;
var process = Package.modules.process;
var Symbol = Package['ecmascript-runtime'].Symbol;
var Map = Package['ecmascript-runtime'].Map;
var Set = Package['ecmascript-runtime'].Set;
var meteorBabelHelpers = Package['babel-runtime'].meteorBabelHelpers;
var Promise = Package.promise.Promise;

/* Package-scope variables */
var Identicon, result;

var require = meteorInstall({"node_modules":{"meteor":{"sandstorm-identicons":{"identicon.js":["babel-runtime/helpers/classCallCheck",function(require){

////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//                                                                                                            //
// packages/sandstorm-identicons/identicon.js                                                                 //
//                                                                                                            //
////////////////////////////////////////////////////////////////////////////////////////////////////////////////
                                                                                                              //
var _classCallCheck2 = require("babel-runtime/helpers/classCallCheck");                                       //
                                                                                                              //
var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);                                              //
                                                                                                              //
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }             //
                                                                                                              //
/**                                                                                                           //
 * Based on:                                                                                                  //
 * Identicon.js v1.0                                                                                          //
 * http://github.com/stewartlord/identicon.js                                                                 //
 *                                                                                                            //
 * Copyright 2013, Stewart Lord                                                                               //
 * Released under the BSD license                                                                             //
 * http://www.opensource.org/licenses/bsd-license.php                                                         //
 */                                                                                                           //
                                                                                                              //
// Trivially modified for Meteor context by Kenton Varda.                                                     //
// Later modified to produce an SVG rather than a PNG.                                                        //
                                                                                                              //
Identicon = function () {                                                                                     // 14
  function Identicon(hash, size, margin) {                                                                    // 15
    (0, _classCallCheck3["default"])(this, Identicon);                                                        // 15
                                                                                                              //
    this.hash = hash;                                                                                         // 16
    this.size = size || 64;                                                                                   // 17
    this.margin = margin || .08;                                                                              // 18
  }                                                                                                           // 19
                                                                                                              //
  Identicon.prototype.render = function render() {                                                            // 14
    var hash = this.hash;                                                                                     // 22
    var size = this.size;                                                                                     // 23
    var margin = size * this.margin;                                                                          // 24
    var cell = (size - margin * 2) / 5;                                                                       // 25
                                                                                                              //
    var rects = [];                                                                                           // 27
                                                                                                              //
    // foreground is last 7 chars as hue at 50% saturation, 70% brightness                                    //
    var rgb = this.hsl2rgb(parseInt(hash.substr(-7), 16) / 0xfffffff, .5, .7);                                // 30
    var fg = "rgb(" + rgb[0] + "," + rgb[1] + "," + rgb[2] + ")";                                             // 31
                                                                                                              //
    // the first 15 characters of the hash control the pixels (even/odd)                                      //
    // they are drawn down the middle first, then mirrored outwards                                           //
    for (var i = 0; i < 15; i++) {                                                                            // 35
      if (!(parseInt(hash.charAt(i), 16) % 2)) {                                                              // 36
        if (i < 5) {                                                                                          // 37
          this.rectangle(2 * cell + margin, i * cell + margin, cell, cell, rects);                            // 38
        } else if (i < 10) {                                                                                  // 39
          this.rectangle(1 * cell + margin, (i - 5) * cell + margin, cell, cell, rects);                      // 40
          this.rectangle(3 * cell + margin, (i - 5) * cell + margin, cell, cell, rects);                      // 41
        } else if (i < 15) {                                                                                  // 42
          this.rectangle(0 * cell + margin, (i - 10) * cell + margin, cell, cell, rects);                     // 43
          this.rectangle(4 * cell + margin, (i - 10) * cell + margin, cell, cell, rects);                     // 44
        }                                                                                                     // 45
      }                                                                                                       // 46
    }                                                                                                         // 47
                                                                                                              //
    // We specify a non-zero stroke width to ensure that adjacent cells connect.                              //
    var strokeWidth = size * 0.005;                                                                           // 50
    return "<svg version=\"1.1\" xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 " + size + " " + size + "\">\n            <rect style=\"fill:rgb(240,240,240)\" x=\"0\" y=\"0\" width=\"" + size + "\" height=\"" + size + "\"/>\n            <g style=\"fill:" + fg + ";stroke-width:" + strokeWidth + ";stroke:" + fg + ";\">\n            " + rects.join("\n") + "</g> </svg>";
  };                                                                                                          // 55
                                                                                                              //
  Identicon.prototype.rectangle = function rectangle(x, y, w, h, rectangles) {                                // 14
    rectangles.push("<rect x=\"" + x + "\" y=\"" + y + "\" width=\"" + w + "\" height=\"" + h + "\"/>");      // 58
  };                                                                                                          // 59
                                                                                                              //
  // adapted from: https://gist.github.com/aemkei/1325937                                                     //
                                                                                                              //
                                                                                                              //
  Identicon.prototype.hsl2rgb = function hsl2rgb(h, s, b) {                                                   // 14
    h *= 6;                                                                                                   // 63
    s = [b += s *= b < .5 ? b : 1 - b, b - h % 1 * s * 2, b -= s *= 2, b, b + h % 1 * s, b + s];              // 64
                                                                                                              //
    return [Math.floor(s[~~h % 6] * 256), // red                                                              // 73
    Math.floor(s[(h | 16) % 6] * 256), // green                                                               // 75
    Math.floor(s[(h | 8) % 6] * 256)];                                                                        // 76
  };                                                                                                          // 78
                                                                                                              //
  // blue                                                                                                     //
                                                                                                              //
  Identicon.prototype.toString = function toString() {                                                        // 14
    return this.render();                                                                                     // 81
  };                                                                                                          // 82
                                                                                                              //
  return Identicon;                                                                                           // 14
}();                                                                                                          // 14
                                                                                                              //
if (Meteor.isServer) {                                                                                        // 85
  (function () {                                                                                              // 85
    // Because identicons are so simple, we can save a lot of bandwidth by applying compression               //
    // before sending them from the server to the client. The PNG format has built-in support for             //
    // lossless compression, but indenticon.js does not take advantage of it. We could work around            //
    // that fact by roundtripping the PNGs through a more complete library like pngjs, or we could            //
    // just apply gzip on top of the suboptimal PNG. We opt for the latter approach.                          //
    var Zlib = Npm.require("zlib");                                                                           // 91
    var gzipSync = Meteor.wrapAsync(Zlib.gzip, Zlib);                                                         // 92
                                                                                                              //
    Identicon.prototype.asAsset = function () {                                                               // 94
      return {                                                                                                // 95
        mimeType: "image/svg+xml",                                                                            // 96
        content: gzipSync(new Buffer(this.render())),                                                         // 97
        encoding: "gzip"                                                                                      // 98
      };                                                                                                      // 95
    };                                                                                                        // 100
  })();                                                                                                       // 85
}                                                                                                             // 101
////////////////////////////////////////////////////////////////////////////////////////////////////////////////

}],"helpers.js":function(){

////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//                                                                                                            //
// packages/sandstorm-identicons/helpers.js                                                                   //
//                                                                                                            //
////////////////////////////////////////////////////////////////////////////////////////////////////////////////
                                                                                                              //
var VALID_USAGES = ["appGrid", "grain"];                                                                      // 1
var checkUsage = function checkUsage(usage) {                                                                 // 2
  if (VALID_USAGES.indexOf(usage) === -1) throw new Error("Invalid icon usage.");                             // 3
};                                                                                                            // 4
                                                                                                              //
var iconFromManifest = function iconFromManifest(manifest, usage) {                                           // 6
  // TODO: select by usage location, rather than assuming appGrid                                             //
  var icons = manifest && manifest.metadata && manifest.metadata.icons ? manifest.metadata.icons : undefined;
  if (icons) {                                                                                                // 10
    if (usage === "appGrid") {                                                                                // 11
      return icons.appGrid;                                                                                   // 12
    } else if (usage === "grain") {                                                                           // 13
      return icons.grain || icons.appGrid;                                                                    // 14
    }                                                                                                         // 15
  }                                                                                                           // 16
                                                                                                              //
  return undefined;                                                                                           // 18
};                                                                                                            // 19
                                                                                                              //
Identicon.hashAppIdForIdenticon = function (id) {                                                             // 21
  // "Hash" an app ID to a 32-digit hex string for the purpose of                                             //
  // producing an identicon. Since app IDs are already high-                                                  //
  // entropy base32 strings, we simply turn each of the first                                                 //
  // 32 digits to base16 by chopping off a bit.                                                               //
                                                                                                              //
  if (!id) return "00000000000000000000000000000000";                                                         // 27
                                                                                                              //
  result = [];                                                                                                // 29
  var digits16 = "0123456789abcdef";                                                                          // 30
  var digits32 = "0123456789acdefghjkmnpqrstuvwxyz";                                                          // 31
  for (var i = 0; i < 32; i++) {                                                                              // 32
    result.push(digits16[digits32.indexOf(id[i]) % 16]);                                                      // 33
  }                                                                                                           // 34
                                                                                                              //
  return result.join("");                                                                                     // 36
};                                                                                                            // 37
                                                                                                              //
// Keep a static global cache of all app identicons produced in this way.                                     //
// If memory usage is excessive, we can revisit this decision.                                                //
var cachedIdenticons = {};                                                                                    // 41
var cachedIdenticon = function cachedIdenticon(hashedAppId, size) {                                           // 42
  var cacheKey = hashedAppId + "-" + size;                                                                    // 43
  if (!cachedIdenticons[cacheKey]) {                                                                          // 44
    var data = new Identicon(hashedAppId, size).toString();                                                   // 45
    cachedIdenticons[cacheKey] = "data:image/svg+xml," + encodeURIComponent(data);                            // 46
  }                                                                                                           // 47
                                                                                                              //
  return cachedIdenticons[cacheKey];                                                                          // 49
};                                                                                                            // 50
                                                                                                              //
var identiconForApp = function identiconForApp(appId, usage) {                                                // 52
  var size = usage === "appGrid" ? 128 : 24;                                                                  // 53
  return cachedIdenticon(Identicon.hashAppIdForIdenticon(appId), size);                                       // 54
};                                                                                                            // 55
                                                                                                              //
var bytesToBase64 = function bytesToBase64(bytes) {                                                           // 57
  var arr = new Array(bytes.length);                                                                          // 58
  for (var i = 0; i < bytes.length; i++) {                                                                    // 59
    arr[i] = String.fromCharCode(bytes[i]);                                                                   // 60
  }                                                                                                           // 61
  // Note that btoa is not available in IE9.  We may want to polyfill this.                                   //
  var result = btoa(arr.join(""));                                                                            // 63
  return result;                                                                                              // 64
};                                                                                                            // 65
                                                                                                              //
var iconSrcFor = function iconSrcFor(appId, iconObj, staticHost, usage) {                                     // 67
  if (iconObj === undefined) {                                                                                // 68
    // Return a identicon src based on hashing appId instead.                                                 //
    // (We hash the appID even though it's already a hash because it's not hex)                               //
    return identiconForApp(appId, usage);                                                                     // 71
  }                                                                                                           // 72
                                                                                                              //
  // TODO(someday): Actually choose the best DPI.                                                             //
  var assetId = iconObj.assetId2xDpi || iconObj.assetId;                                                      // 75
  if (assetId) {                                                                                              // 76
    var src = window.location.protocol + "//" + staticHost + "/" + assetId;                                   // 77
    return src;                                                                                               // 78
  }                                                                                                           // 79
                                                                                                              //
  if (iconObj.svg) {                                                                                          // 81
    // iconObj.svg is a text string, so we can base64 it directly                                             //
    // Note that btoa is not available in IE9.  We may want to polyfill this.                                 //
    return "data:image/svg+xml;base64," + btoa(iconObj.svg);                                                  // 84
  }                                                                                                           // 85
                                                                                                              //
  if (iconObj.png) {                                                                                          // 87
    // TODO(someday): Actually choose the best DPI.                                                           //
    var png = iconObj.png.dpi2x || iconObj.png.dpi1x;                                                         // 89
    var data = void 0;                                                                                        // 90
    if (png) {                                                                                                // 91
      // png is a Uint8Array, so we need to convert it to text before calling btoa.                           //
      // Yes, the irony is profound.                                                                          //
      data = bytesToBase64(png);                                                                              // 94
      return "data:image/png;base64," + data;                                                                 // 95
    }                                                                                                         // 96
  }                                                                                                           // 97
  // We should never reach here, but do something sensible anyway                                             //
  return identiconForApp(appId, usage);                                                                       // 99
};                                                                                                            // 100
                                                                                                              //
Identicon.identiconForApp = function (appId, usage) {                                                         // 102
  return identiconForApp(appId, usage);                                                                       // 103
};                                                                                                            // 104
                                                                                                              //
Identicon.iconSrcForPackage = function (pkg, usage, staticHost) {                                             // 106
  // Works for regular packages and dev packages.                                                             //
                                                                                                              //
  checkUsage(usage);                                                                                          // 109
  var iconObj = iconFromManifest(pkg.manifest, usage);                                                        // 110
  return iconSrcFor(pkg.appId, iconObj, staticHost, usage);                                                   // 111
};                                                                                                            // 112
                                                                                                              //
Identicon.iconSrcForDenormalizedGrainMetadata = function (metadata, usage, staticHost) {                      // 114
  return iconSrcFor(metadata.appId, metadata.icon, staticHost, usage);                                        // 115
};                                                                                                            // 116
////////////////////////////////////////////////////////////////////////////////////////////////////////////////

}}}}},{"extensions":[".js",".json"]});
require("./node_modules/meteor/sandstorm-identicons/identicon.js");
require("./node_modules/meteor/sandstorm-identicons/helpers.js");

/* Exports */
if (typeof Package === 'undefined') Package = {};
(function (pkg, symbols) {
  for (var s in symbols)
    (s in pkg) || (pkg[s] = symbols[s]);
})(Package['sandstorm-identicons'] = {}, {
  Identicon: Identicon
});

})();

//# sourceMappingURL=sandstorm-identicons.js.map
